essential_types::predicate::header

Struct DecodedHeader

pub struct DecodedHeader<'a> {
    pub state_reads: &'a [u8],
    pub constraints: &'a [u8],
}
The header of a Predicate decoded. This contains the indices of the Predicate’s data in a buffer.

Fields

state_reads: &'a [u8]

The indices of the state read programs in a buffer.

constraints: &'a [u8]

The indices of the constraint check programs in a buffer.

Implementations

Source

impl<'a> DecodedHeader<'a>

pub fn bytes_len(&self) -> usize

The number of bytes this header points to.

This includes the EncodedFixedSizeHeader::SIZE and the lengths of the programs as well as the programs themselves.

pub fn decode(buf: &'a [u8]) -> Result<Self, DecodeError>

Decode a header from bytes.

Errors

Returns an error if the buffer is too small or the header is inconsistent or the predicate bounds are beyond the limits.