pub struct DecodedHeader<'a> {
pub state_reads: &'a [u8],
pub constraints: &'a [u8],
}Expand description
Fields
state_reads: &'a [u8]The indices of the state read programs in a buffer.
constraints: &'a [u8]The indices of the constraint check programs in a buffer.
Implementations
Sourceimpl<'a> DecodedHeader<'a>
impl<'a> DecodedHeader<'a>
Sourcepub fn bytes_len(&self) -> usize
pub fn bytes_len(&self) -> usize
The number of bytes this header points to.
This includes the EncodedFixedSizeHeader::SIZE
and the lengths of the programs as well as the programs themselves.